@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2018 Canonical, Ltd.
+# Copyright (c) 2015-2021 Canonical, Ltd.
 #
 # This file is part of Talisker
 # (see http://github.com/canonical-ols/talisker).
@@ -22,12 +22,6 @@
 #
 
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-
-from builtins import *  # noqa
 import logging
 import sys
 import textwrap
@@ -48,7 +42,7 @@ from talisker.context import (  # NOQA
     request_timeout,
 )
 
-__version__ = '0.19.0'
+__version__ = '0.21.1'
 __all__ = [
     'initialise',
     'get_config',
@@ -194,7 +188,7 @@ def run_help():
                 )
 
 
-def run_celery(argv=sys.argv):
+def run_celery():
     initialise()
     os.environ['CELERYD_REDIRECT_STDOUTS'] = 'False'
     # technically we don't need this, as we disable celery's logging
@@ -205,7 +199,7 @@ def run_celery(argv=sys.argv):
     from celery.bin.celery import main
     talisker.celery.enable_signals()
     clear_context()
-    main(argv)
+    main()
 
 
 def run_gunicorn():
